==> haskell-alsa-core-0.5.0.1-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-alsa-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 alsa-core
version:              0.5.0.1
visibility:           public
id:                   alsa-core-0.5.0.1-EyKLeSfRKRzH2VWenP6BXN
key:                  alsa-core-0.5.0.1-EyKLeSfRKRzH2VWenP6BXN
license:              BSD-3-Clause
copyright:            Bjorn Bringert, Iavor S. Diatchki, Henning Thielemann
maintainer:           Henning Thielemann <alsa@henning-thielemann.de>
author:
    Henning Thielemann <alsa@henning-thielemann.de>, Bjorn Bringert <bjorn@bringert.net>, Iavor S. Diatchki <iavor.diatchki@gmail.com>

stability:            Experimental
homepage:             http://www.haskell.org/haskellwiki/ALSA
synopsis:             Binding to the ALSA Library API (Exceptions).
description:
    This package provides access to ALSA infrastructure,
    that is needed by both alsa-seq and alsa-pcm.

category:             Sound, Music
abi:                  5cc063f538413413e657f9ae41b7eb94
exposed:              True
exposed-modules:      Sound.ALSA.Exception
import-dirs:          /usr/lib/ghc-9.0.1/site-local/alsa-core-0.5.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/alsa-core-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/alsa-core-0.5.0.1
hs-libraries:         HSalsa-core-0.5.0.1-EyKLeSfRKRzH2VWenP6BXN
extra-libraries:      asound
depends:
    base-4.15.0.0 extensible-exceptions-0.1.1.4-78NMIT9qofYFWl0e48Yw92

haddock-interfaces:   /usr/share/doc/haskell-alsa-core/html/alsa-core.haddock
haddock-html:         /usr/share/doc/haskell-alsa-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-alsa-core-0.5.0.1-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-alsa-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 alsa-core
version:              0.5.0.1
visibility:           public
id:                   alsa-core-0.5.0.1-IuG6WQnGAn47tOy9J9GFFS
key:                  alsa-core-0.5.0.1-IuG6WQnGAn47tOy9J9GFFS
license:              BSD-3-Clause
copyright:            Bjorn Bringert, Iavor S. Diatchki, Henning Thielemann
maintainer:           Henning Thielemann <alsa@henning-thielemann.de>
author:
    Henning Thielemann <alsa@henning-thielemann.de>, Bjorn Bringert <bjorn@bringert.net>, Iavor S. Diatchki <iavor.diatchki@gmail.com>

stability:            Experimental
homepage:             http://www.haskell.org/haskellwiki/ALSA
synopsis:             Binding to the ALSA Library API (Exceptions).
description:
    This package provides access to ALSA infrastructure,
    that is needed by both alsa-seq and alsa-pcm.

category:             Sound, Music
abi:                  949539fdaa61cbc8b3148fdd3077bd09
exposed:              True
exposed-modules:      Sound.ALSA.Exception
import-dirs:          /usr/lib/ghc-9.0.2/site-local/alsa-core-0.5.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/alsa-core-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/alsa-core-0.5.0.1
hs-libraries:         HSalsa-core-0.5.0.1-IuG6WQnGAn47tOy9J9GFFS
extra-libraries:      asound
depends:
    base-4.15.1.0 extensible-exceptions-0.1.1.4-FO4Sw13oBkvBW8j4vnJTpA

haddock-interfaces:   /usr/share/doc/haskell-alsa-core/html/alsa-core.haddock
haddock-html:         /usr/share/doc/haskell-alsa-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
